@@ -1,41 +1,31 @@
-from __future__ import print_function
-import brotli
-import io
-import socket
-import ssl
+from http import cookies
+from io import BytesIO
+import base64
+import encodings
 import errno
-import time
 import gzip
 import os
-import sys
 import re
-import base64
+import socket
+import ssl
+import sys
+import time
 import zlib
-import encodings
+
+import brotli
 from IPy import IP
 
-from six import BytesIO, PY2, ensure_binary, ensure_str, iteritems, \
-    text_type
-from six.moves import http_cookies
-
 from . import errors
+from . import util
 
 
 # Fallback to PROTOCOL_SSLv23 if PROTOCOL_TLS is not available.
-PROTOCOL_TLS = getattr(ssl, "PROTOCOL_TLS", ssl.PROTOCOL_SSLv23)
-
-
-if PY2:
-    reload(sys)  # pragma: no flakes
-    sys.setdefaultencoding('utf8')
-    escape_codec = 'string_escape'
-else:
-    escape_codec = 'unicode_escape'
+PROTOCOL_TLS = getattr(ssl, 'PROTOCOL_TLS', ssl.PROTOCOL_SSLv23)
 
 
 class HttpResponse(object):
     def __init__(self, http_response, user_agent):
-        self.response = ensure_binary(http_response)
+        self.response = util.ensure_binary(http_response)
         # For testing purposes HTTPResponse might be called OOL
         try:
             self.dest_addr = user_agent.request_object.dest_addr
@@ -106,7 +96,7 @@ class HttpResponse(object):
             IP(self.dest_addr)
         except ValueError:
             origin_is_ip = False
-        for cookie_morsals in cookie.values():
+        for cookie_morsals in list(cookie.values()):
             # If the coverdomain is blank or the domain is an IP
             # set the domain to be the origin
             if cookie_morsals['domain'] == '' or origin_is_ip:
@@ -126,8 +116,8 @@ class HttpResponse(object):
                 cover_domain = cover_domain[first_non_dot:]
                 # We must parse the coverDomain to make sure its
                 # not in the suffix list
-                psl_path = os.path.dirname(__file__) + os.path.sep + \
-                    'util' + os.path.sep + 'public_suffix_list.dat'
+                psl_path = os.path.join(os.path.dirname(__file__),
+                                        'util', 'public_suffix_list.dat')
                 # Check if the public suffix list is present in the ftw dir
                 if os.path.exists(psl_path):
                     pass
@@ -139,7 +129,7 @@ class HttpResponse(object):
                             'function': 'http.HttpResponse.check_for_cookie'
                         })
                 try:
-                    with io.open(psl_path, 'r', encoding='utf-8') as fo:
+                    with open(psl_path, 'r', encoding='utf-8') as fo:
                         for line in fo:
                             if line[:2] == '//' or line[0] == ' ' or \
                                line[0].strip() == '':
@@ -185,7 +175,7 @@ class HttpResponse(object):
         Parses an HTTP response after an HTTP request is sent
         """
         split_response = self.response.split(self.CRLF)
-        response_line = ensure_str(split_response[0])
+        response_line = util.ensure_str(split_response[0])
         response_headers = {}
         response_data = None
         data_line = None
@@ -204,13 +194,13 @@ class HttpResponse(object):
                             'header_rcvd': str(header),
                             'function': 'http.HttpResponse.process_response'
                         })
-                header = ensure_str(header[0]), ensure_str(header[1])
+                header = util.ensure_str(header[0]), util.ensure_str(header[1])
                 response_headers[header[0].lower()] = header[1].lstrip()
-        if 'set-cookie' in response_headers.keys():
+        if 'set-cookie' in list(response_headers.keys()):
             try:
-                cookie = http_cookies.SimpleCookie()
+                cookie = cookies.SimpleCookie()
                 cookie.load(response_headers['set-cookie'])
-            except http_cookies.CookieError as err:
+            except cookies.CookieError as err:
                 raise errors.TestError(
                     'Error processing the cookie content into a SimpleCookie',
                     {
@@ -232,7 +222,7 @@ class HttpResponse(object):
             response_data = self.CRLF.join(split_response[data_line:])
 
         # if the output headers say there is encoding
-        if 'content-encoding' in response_headers.keys():
+        if 'content-encoding' in list(response_headers.keys()):
             response_data = self.parse_content_encoding(
                 response_headers, response_data)
         if len(response_line.split(' ', 2)) != 3:
@@ -333,7 +323,7 @@ class HttpUA(object):
         return_cookies = []
         origin_domain = self.request_object.dest_addr
         for cookie in self.cookiejar:
-            for cookie_morsals in cookie[0].values():
+            for cookie_morsals in list(cookie[0].values()):
                 cover_domain = cookie_morsals['domain']
                 if cover_domain == '':
                     if origin_domain == cookie[1]:
@@ -361,12 +351,12 @@ class HttpUA(object):
         # If the user has requested a tracked cookie and we have one set it
         if available_cookies:
             cookie_value = ''
-            if 'cookie' in self.request_object.headers.keys():
+            if 'cookie' in list(self.request_object.headers.keys()):
                 # Create a SimpleCookie out of our provided cookie
                 try:
-                    provided_cookie = http_cookies.SimpleCookie()
+                    provided_cookie = cookies.SimpleCookie()
                     provided_cookie.load(self.request_object.headers['cookie'])
-                except http_cookies.CookieError as err:
+                except cookies.CookieError as err:
                     raise errors.TestError(
                         'Error processing the existing cookie into a '
                         'SimpleCookie',
@@ -377,29 +367,29 @@ class HttpUA(object):
                             'function': 'http.HttpResponse.build_request'
                         })
                 result_cookie = {}
-                for cookie_key, cookie_morsal in iteritems(provided_cookie):
+                for cookie_key, cookie_morsal in list(provided_cookie.items()):
                     result_cookie[cookie_key] = \
                         provided_cookie[cookie_key].value
                 for cookie in available_cookies:
-                    for cookie_key, cookie_morsal in iteritems(cookie):
-                        if cookie_key in result_cookie.keys():
+                    for cookie_key, cookie_morsal in cookie:
+                        if cookie_key in list(result_cookie.keys()):
                             # we don't overwrite a user specified
                             # cookie with a saved one
                             pass
                         else:
                             result_cookie[cookie_key] = \
                                 cookie[cookie_key].value
-                for key, value in iteritems(result_cookie):
-                    cookie_value += (text_type(key) + '=' +
-                                     text_type(value) + '; ')
+                for key, value in list(result_cookie.items()):
+                    cookie_value += (str(key) + '=' +
+                                     str(value) + '; ')
                     # Remove the trailing semicolon
                 cookie_value = cookie_value[:-2]
                 self.request_object.headers['cookie'] = cookie_value
             else:
                 for cookie in available_cookies:
-                    for cookie_key, cookie_morsal in iteritems(cookie):
-                        cookie_value += (text_type(cookie_key) + '=' +
-                                         text_type(cookie_morsal.coded_value) +
+                    for cookie_key, cookie_morsal in list(cookie.items()):
+                        cookie_value += (str(cookie_key) + '=' +
+                                         str(cookie_morsal.coded_value) +
                                          '; ')
                         # Remove the trailing semicolon
                     cookie_value = cookie_value[:-2]
@@ -408,18 +398,18 @@ class HttpUA(object):
         # Expand out our headers into a string
         headers = ''
         if self.request_object.headers != {}:
-            for hname, hvalue in iteritems(self.request_object.headers):
-                headers += text_type(hname) + ': ' + \
-                    text_type(hvalue) + self.CRLF
+            for hname, hvalue in self.request_object.headers.items():
+                headers += str(hname) + ': ' + \
+                    str(hvalue) + self.CRLF
         request = request.replace('#headers#', headers)
 
         # If we have data append it
         if self.request_object.data != '':
             # Before we do that see if that is a charset
-            encoding = "utf-8"
+            encoding = 'utf-8'
             # Check to see if we have a content type and magic is
             # off (otherwise UTF-8)
-            if 'Content-Type' in self.request_object.headers.keys() and \
+            if 'Content-Type' in list(self.request_object.headers.keys()) and \
                self.request_object.stop_magic is False:
                 pattern = re.compile(r'\;\s{0,1}?charset\=(.*?)(?:$|\;|\s)')
                 m = re.search(pattern,
@@ -435,20 +425,24 @@ class HttpUA(object):
                     if choice in possible_choices:
                         encoding = choice
             try:
-                data = self.request_object.data.encode(encoding)
-            except UnicodeEncodeError as err:
+                data_bytes = \
+                    self.request_object.data.encode(encoding, 'strict')
+            except UnicodeError as err:
                 raise errors.TestError(
                     'Error encoding the data with the charset specified',
                     {
                         'msg': str(err),
                         'Content-Type':
                             str(self.request_object.headers['Content-Type']),
-                        'data': text_type(self.request_object.data),
+                        'data': str(self.request_object.data),
                         'function': 'http.HttpResponse.build_request'
                     })
-            request = request.replace('#data#', ensure_str(data))
+            data = util.ensure_str(data_bytes)
         else:
-            request = request.replace('#data#', '')
+            data = ''
+
+        request = request.replace('#data#', data).encode('utf-8', 'strict')
+
         # If we have a Raw Request we should use that instead
         if self.request_object.raw_request is not None:
             if self.request_object.encoded_request is not None:
@@ -457,15 +451,16 @@ class HttpUA(object):
                     {
                         'function': 'http.HttpUA.build_request'
                     })
-            request = ensure_binary(self.request_object.raw_request)
+            request = self.request_object.raw_request.encode('utf-8', 'strict')
             # We do this regardless of magic if you want to send a literal
             # '\' 'r' or 'n' use encoded request.
-            request = request.decode(escape_codec)
+            request = request.decode('unicode_escape')
+
         if self.request_object.encoded_request is not None:
             request = base64.b64decode(self.request_object.encoded_request)
-            request = request.decode(escape_codec)
-        # if we have an Encoded request we should use that
-        self.request = ensure_binary(request)
+
+        # Use the request created
+        self.request = util.ensure_binary(request)
 
     def get_response(self):
         """
@@ -486,7 +481,7 @@ class HttpUA(object):
             try:
                 data = self.sock.recv(self.RECEIVE_BYTES)
                 if data:
-                    our_data.append(ensure_binary(data))
+                    our_data.append(util.ensure_binary(data))
                     begin = time.time()
                 else:
                     # Sleep for sometime to indicate a gap
