@@ -1,9 +1,8 @@
 import re
-
-from six import ensure_str
-from six.moves.urllib.parse import parse_qsl, unquote, urlencode
+from urllib.parse import parse_qsl, unquote, urlencode
 
 from . import errors
+from . import util
 
 
 class Output(object):
@@ -115,18 +114,20 @@ class Input(object):
         # Check if there is any data and do defaults
         if self.data != '':
             # Default values for content length and header
-            if 'Content-Type' not in headers.keys() and stop_magic is False:
+            if 'Content-Type' not in list(headers.keys()) and \
+               stop_magic is False:
                 headers['Content-Type'] = 'application/x-www-form-urlencoded'
             # check if encoded and encode if it should be
-            if 'Content-Type' in headers.keys():
+            if 'Content-Type' in list(headers.keys()):
                 if headers['Content-Type'] == \
                    'application/x-www-form-urlencoded' and stop_magic is False:
-                    if ensure_str(unquote(self.data)) == self.data:
+                    if util.ensure_str(unquote(self.data)) == self.data:
                         query_string = parse_qsl(self.data)
                         if len(query_string) != 0:
                             encoded_args = urlencode(query_string)
                             self.data = encoded_args
-            if 'Content-Length' not in headers.keys() and stop_magic is False:
+            if 'Content-Length' not in list(headers.keys()) and \
+               stop_magic is False:
                 # The two is for the trailing CRLF and the one after
                 headers['Content-Length'] = len(self.data)
 
@@ -159,10 +160,8 @@ class Test(object):
         """
         Processes and loads an array of stages from the test dictionary
         """
-        return map(
-            lambda stage_dict: Stage(stage_dict['stage']),
-            self.test_dict['stages']
-        )
+        return [Stage(stage_dict['stage'])
+                for stage_dict in self.test_dict['stages']]
 
 
 class Ruleset(object):
@@ -184,10 +183,8 @@ class Ruleset(object):
         creates test objects based on input
         """
         try:
-            return map(
-                lambda test_dict: Test(test_dict, self.meta),
-                self.yaml_file['tests']
-            )
+            return [Test(test_dict, self.meta)
+                    for test_dict in self.yaml_file['tests']]
         except errors.TestError as e:
             e.args[1]['meta'] = self.meta
             raise e
