@@ -1,10 +1,8 @@
-from __future__ import print_function
 import datetime
-from dateutil import parser
-import pytest
 import sqlite3
 
-from six import ensure_str
+from dateutil import parser
+import pytest
 
 from . import errors
 from . import http
@@ -57,7 +55,7 @@ class TestRunner(object):
                     'response_object': response_object,
                     'function': 'testrunner.TestRunner.test_response'
                 })
-        if regex.search(ensure_str(response_object.response)):
+        if regex.search(util.ensure_str(response_object.response)):
             assert True
         else:
             assert False
@@ -67,7 +65,7 @@ class TestRunner(object):
         Checks if the response response contains a regex specified in the
         output stage. It will assert that the regex is present.
         """
-        if regex.search(ensure_str(response)):
+        if regex.search(util.ensure_str(response)):
             assert True
         else:
             assert False
@@ -99,10 +97,10 @@ class TestRunner(object):
         conn.text_factory = str
         cur = conn.cursor()
         for i, stage in enumerate(test.stages):
-            '''
+            """
             Query DB here for rule_id & test_title
             Compare against logger_obj
-            '''
+            """
             q = self.query_for_stage_results(tablename)
             results = cur.execute(q, [i, test.test_title]).fetchall()
             if len(results) == 0:
