@@ -1,6 +1,7 @@
 import pytest
 from ftw import testrunner, errors
 
+
 def test_default(ruleset, test, destaddr, port, protocol):
     """
     Default tester with no logger obj. Useful for HTML contains and Status code
@@ -18,5 +19,5 @@ def test_default(ruleset, test, destaddr, port, protocol):
             runner.run_stage(stage, None)
     except errors.TestError as e:
         e.args[1]['meta'] = ruleset.meta
-        pytest.fail('Failure! Message -> {0}, Context -> {1}'
-                        .format(e.args[0],e.args[1]))
+        pytest.fail('Failure! Message -> {0}, Context -> {1}'.format(
+                    e.args[0], e.args[1]))
